@@ -5,20 +5,20 @@ use strict;
 use warnings;
 use HTML::Entities;
 
-our $VERSION = '0.07_01';
+our $VERSION = '0.03';
 
-use Exporter;
+use Exporter 'import';
 use Carp;
 
 our @ISA = qw(Exporter);
 
 BEGIN {
-	Exporter::import 'jsFind::Node';
+	import 'jsFind::Node';
 }
 
 =head1 NAME
 
-jsFind - generate index for full text search engine in JavaScript
+jsFind - generate index for jsFind using B-Tree
 
 =head1 SYNOPSIS
 
@@ -53,57 +53,12 @@ You don't need to use swish-e to create index
 
 =item *
 
-you can programatically (and incrementaly) create index for jsFind
-
-=item *
-
-you can create more than one index and search them using same C<search.html>
-page
+You can programatically (and incrementaly) create index for jsFind
 
 =back
 
 You can also examine examples which come as tests with this module,
-for example C<t/04words.t> or C<t/10homer.t>.
-
-=head2 jsFind
-
-jsFind search engine was written by Shawn Garbett from eLucid Software.
-The search engine itself is a small piece of JavaScript (1.2 with level 2
-DOM). It is easily customizable to fit into a current set of HTML. This
-JavaScript searches an XML index dataset for the appropriate links, and can
-filter and sort the results.
-
-JavaScript code distributed with this module is based on version 0.0.3 which
-was current when this module development started. Various changes where done
-on JavaScript code to fix bugs, add features and remove warnings. For
-complete list see C<Changes> file which comes with distribution.
-
-This module has been tested using C<html/test.html> with following browsers:
-
-=over 5
-
-=item Mozilla FireFox 0.8 to 1.0
-
-using DOM 2 C<document.implementation.createDocument>
-
-=item Internet Explorer 5.5 and 6.0
-
-using ActiveX C<Microsoft.XMLDOM> or C<MSXML2.DOMDocument>
-
-=item Konqueror 3.3
-
-using DOM 2 C<document.implementation.createDocument>
-
-=item Opera 7.54 (without Java)
-
-using experimental iframe implementation which is much slower than other methods.
-
-=back
-
-If searching doesn't work for your combination of operating system and
-browser, please open C<html/test.html> file and wait a while. It will search sample
-file included with distribution and report results. Reports with included
-test debugging are welcomed.
+for example C<t/04words.t>.
 
 =head1 jsFind methods
 
@@ -358,55 +313,18 @@ sub to_dot {
 Create xml index files for jsFind. This should be called after
 your B-Tree has been filled with data.
 
- $root->to_jsfind(
- 	dir => '/full/path/to/index/dir/',
-	data_codepage => 'ISO-8859-2',
-	index_codepage => 'UTF-8',
-	output_filter => sub {
-		my $t = shift || return;
-		$t =~ s/&egrave;/e/;
-	}
- );
-
-All options except C<dir> are optional.
+ $root->to_jsfind('/full/path/to/index/dir/');
 
 Returns number of nodes in created tree.
 
-Options:
+There is also longer version if you want to recode your data charset
+into different one (probably UTF-8):
 
-=over 4
+ $root->to_jsfind('/full/path/to/index/dir/','ISO-8859-2','UTF-8');
 
-=item dir
+Destination encoding is UTF-8 by default, so you don't have to specify it.
 
-Full path to directory for index (which will be created if needed).
-
-=item data_codepage
-
-If your imput data isn't in C<ISO-8859-1> encoding, you will have to specify
-this option.
-
-=item index_codepage
-
-If your index encoding is not C<UTF-8> use this option.
-
-If you are not using supplied JavaScript search code, or your browser is
-terribly broken and thinks that index shouldn't be in UTF-8 encoding, use
-this option to specify encoding for created XML index.
-
-=item output_filter
-
-B<this is just draft of documentation for option which is not implemented!>
-
-Code ref to sub which can do modifications on resulting XML file for node.
-Encoding of this data will be in L<index_codepage> and you have to take care
-not to break XML structure. Calling L<xmllint> on your result index
-(like C<t/90xmllint.t> does in this distribution) is a good idea after using
-this option.
-
-This option is also right place to plug in unaccenting function using
-L<Text::Unaccent>.
-
-=back
+ $root->to_jsfind('/full/path/to/index/dir/','WINDOWS-1250');
 
 =cut
 
@@ -416,22 +334,21 @@ my $iconv_l1;
 sub to_jsfind {
 	my $self = shift;
 
-	my %arg = @_;
+	my $path = shift || confess "to_jsfind need path to your index!";
 
-	confess "to_jsfind need path to your index directory !" unless ($arg{'dir'});
+	my ($from_cp,$to_cp) = @_;
 
-	my $data_codepage = $arg{'data_codepage'};
-	my $index_codepage = $arg{'index_codepage'} || 'UTF-8';
+	$to_cp ||= 'UTF-8';
 
-	# create ISO-8859-1 iconv for HTML::Entities decode
-	$iconv_l1 = Text::Iconv->new('ISO-8859-1',$index_codepage);
-
-	# create another iconv for data
-	if ($data_codepage && $index_codepage) {
-		$iconv = Text::Iconv->new($data_codepage,$index_codepage);
+	if ($from_cp && $to_cp) {
+		$iconv = Text::Iconv->new($from_cp,$to_cp);
 	}
+	$iconv_l1 = Text::Iconv->new('ISO-8859-1',$to_cp);
 
-	return $self->root->to_jsfind($arg{'dir'},"0");
+	$path .= "/" if ($path =~ /\/$/);
+	#carp "creating directory for index '$path'" if (! -w $path);
+
+	return $self->root->to_jsfind($path,"0");
 }
 
 
@@ -490,7 +407,6 @@ use strict;
 use Carp;
 use File::Path;
 use Text::Iconv;
-use POSIX;
 
 use base 'jsFind';
 
@@ -860,46 +776,6 @@ sub to_xml {
 	return $d;
 }
 
-=head2 base_x
-
-Convert number to base x (used for jsFind index filenames).
-
- my $n = $tree->base_x(50);
-
-=cut
-
-sub base_x {
-	my $self = shift;
-
-	my $value = shift;
-
-	confess("need non-negative number") if (! defined($value) || $value < 0);
-
-	my @digits = qw(
-		0 1 2 3 4 5 6 7 8 9
-		a b c d e f g h i j k l m n o p q r s t u v w x y z
-	);
-
-	my $base = scalar(@digits);
-	my $out = "";
-	my $pow = 1;
-	my $pos = 0;
-
-
-	if($value == 0) {
-		return "0";
-	}
-
-	while($value > 0) {
-		$pos = $value % $base;
-		$out = $digits[$pos] . $out;
-		$value = floor($value/$base);
-		$pow *= $base;
-	}
-
-	return $out;
-}
-
 =head2 to_jsfind
 
 Create jsFind xml files
@@ -910,6 +786,7 @@ Returns number of elements created
 
 =cut
 
+
 sub to_jsfind {
 	my $self = shift;
 	my ($path,$file) = @_;
@@ -919,8 +796,6 @@ sub to_jsfind {
 	confess("path is undefined.") unless ($path);
 	confess("file is undefined. Did you call \$t->root->to_jsfind(..) instead of \$t->to_jsfind(..) ?") unless (defined($file));
 
-	$file = $self->base_x($file);
-
 	my $nr_keys = 0;
 
 	my ($k, $d, $s) = @$self;
